==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'pou bann zartik a fèr sèlman (san tous a ryin dann bazdodné).',
	'bouton_radio_articles_tous' => 'po TOUT bann zartik minm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pou tout bann zartik-la, sof banna pwinn bordé èk inn forom kozman.',
	'bouton_radio_enregistrement_obligatoire' => 'Aou lé néséser fé zwé lanrozistroman po anvwa out komisyon (bann zitilzatèr i dwa mèt ladrès imèl pou abonn azot).',
	'bouton_radio_moderation_priori' => 'Modèr-dovan (bann komisyon lé publyé dann figirwèb piblik, sèlman kan komandèr la apiyé).

', # MODIF
	'bouton_radio_modere_abonnement' => 'In labonman lé nesèsèr',
	'bouton_radio_modere_posteriori' => 'lé modèré apré konfirmasyon ', # MODIF
	'bouton_radio_modere_priori' => 'lé modèré-dovan', # MODIF
	'bouton_radio_publication_immediate' => 'Modékri lé publyé sir losan (bann komisyon lé visib toutswit apré zot la anvway ali ; bann komander sitwèb i pé dégrèn ali aprè).',

	// F
	'form_pet_message_commentaire' => 'Inn modékri, inn ti lavi, inn komantèr ?',
	'forum' => 'Forom kozman',
	'forum_acces_refuse' => 'Ou néna pli lapermisyon pou gèt dann bann forom-la.',
	'forum_attention_dix_caracteres' => '<b>Tansyon pangar !</b> out modékri néna mwin 10 karaktèr-linprimri. Lé pa asé pou anrozistr ali.',
	'forum_attention_trois_caracteres' => '<b>Tansyon pangar !</b> Lo non ou la doné nana mwin 3 karactèr-linprimri.Sa lé pa asé pou anrozistr ali.',
	'forum_attention_trop_caracteres' => '<b>TANSYON@circ@ !</b> out’ mèzaz lé tro long’ (@compte@ karaktèr-linprimri)@circ@ : pour giny anrozistré, li doi pa fé pli dé @max@ karaktèr-linprimri', # MODIF
	'forum_avez_selectionne' => 'Ou la swazi :',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>tèrla</a> pour asévé.',
	'forum_forum' => 'forom kozman',
	'forum_info_modere' => 'Forom kozman lé modéré-dovan : lé néséser inn komander la finn konfirm ali pour out kontribusyon i aparé an liyn.

', # MODIF
	'forum_lien_hyper' => '<b>Gatiraz</b> (lé pa obligatwar)', # MODIF
	'forum_message_definitif' => 'Modékri-la lé fini : anvwa ali si lo sitwèb',
	'forum_message_trop_long' => 'Out modékri lé tro lon. Li dwa pa dépas plid 20000 karaktèr-linprimri.', # MODIF
	'forum_ne_repondez_pas' => 'Pou réponn limél-la, anserv lo forom kozman ou sava trouv tèrla (réponn pa èk inn ot limèl mé zizt inn modékri sir lo sitwèb) :', # MODIF
	'forum_page_url' => '(Si out modékri li ranvwa si inn lartik si lo Wèb o inn ot paz pli konplé déor, mèrsi mèt anba lo non lapazwèb èk son ladrès URL.)',
	'forum_poste_par' => 'Modékri-la, @parauteur@ la post ali pou réponn out lartik.', # MODIF
	'forum_qui_etes_vous' => '<b>Kisa ou lé ?</b> (réponn lé pa obligatwar)', # MODIF
	'forum_texte' => 'Lo tèks out modékri :', # MODIF
	'forum_titre' => 'Non :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Konfirm out swa',
	'forum_voir_avant' => 'Artourn gét modékri-la avann konfirm ali', # MODIF
	'forum_votre_email' => 'Out ladrès imèl :', # MODIF
	'forum_votre_nom' => 'Out vrénon (ou ti-non-gaté) :', # MODIF
	'forum_vous_enregistrer' => 'Pou mèt ansanm dann forom-la, ifo anrozistr aou. Mersi pou mèt anba latèr nondkod-lidantité sak ni la donn aou. Si ou lé pa anrozistré, i dwa',
	'forum_vous_inscrire' => 'inskri a ou </a>.',

	// I
	'icone_poster_message' => 'Anvwa inn modékri',
	'icone_suivi_forum' => 'Swiv lo forom piblik sir figirwèb : @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'Swiv/aranz bann forom',
	'icone_supprimer_message' => 'Dégrèn modékri-la',
	'icone_valider_message' => 'Konfirm modékri-la',
	'info_activer_forum_public' => '<i>Swazi inn manyir lamodérasyon otomatik pou bann forom piblik :</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplik lo swa ou la fé pou lamodérasyon :',
	'info_desactiver_forum_public' => 'Apiy tèrla, pou détour litilizasyon tout bann forom piblik. Ou sra touzou kav permèt bann forom-la èk bann zartik (dann désertin ka ou sava désid) ; mé nora pwinn forom èk bann rubrik, bann tit-nouvèl, é tousala.',
	'info_envoi_forum' => 'Anvwa tout bann modékri sak i sort dann bann forom , pou tout bann lotèr lartik lyé ',
	'info_fonctionnement_forum' => 'Koman forom-la i pé roul ron :',
	'info_gauche_suivi_forum_2' => 'Paz <i>swivi bann forom</i> lé inn zoutiy pou zèr an liyn out sit (pa inn léspas kozman o lékritir). Li afis tout bann kontribusyon sak lé prézanté dann tout bann forom out sit i ébèrz (kiswa forom-dodan, forom-déor, tousala...). Li permé zèr bann kontribusyon-la.', # MODIF
	'info_liens_syndiques_3' => 'bann forom',
	'info_liens_syndiques_4' => 'lé',
	'info_liens_syndiques_5' => 'forom',
	'info_liens_syndiques_6' => 'lé',
	'info_liens_syndiques_7' => 'i espèr lakonfirmasyon',
	'info_mode_fonctionnement_defaut_forum_public' => 'Lo fonksionman otomatik (sanswa) pou bann forom-déor (piblik)',
	'info_option_email' => 'Kank inn vizitèr i mèt inn modékri dann forom sou inn lartik
bann lotèr i pé konèt a li
sanm inn limèl. Indik tèrla si ou vé anserv lopsyon-la ?', # MODIF
	'info_pas_de_forum' => 'néna pwinn forom',
	'item_activer_forum_administrateur' => 'Fé zwé lo forom bann komandèr',
	'item_desactiver_forum_administrateur' => 'Défalk bann forom-komandèr',

	// L
	'lien_reponse_article' => 'Réponn lartik-la',
	'lien_reponse_breve_2' => 'Répons pou tit-nouvèl',
	'lien_reponse_rubrique' => 'Répons pou rubrik-la',
	'lien_reponse_site_reference' => 'Répons pou sit-la :', # MODIF

	// O
	'onglet_messages_internes' => 'Bann modékri-dodan',
	'onglet_messages_publics' => 'Bann modékri-déor',
	'onglet_messages_vide' => 'Bann modékri san tèks',

	// R
	'repondre_message' => 'Po réponn modékri-la',

	// T
	'titre_cadre_forum_administrateur' => 'Forom privé bann komandèr',
	'titre_cadre_forum_interne' => 'Forom dodan',
	'titre_forum' => 'Forom ',
	'titre_forum_suivi' => 'Swivi bann forom',
	'titre_page_forum_suivi' => 'Swivi bann forom'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'pou bann zartik a fèr sèlman (san tous a ryin dann bazdodné).',
	'bouton_radio_articles_tous' => 'po TOUT bann zartik minm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pou tout bann zartik-la, sof banna pwinn bordé èk inn forom kozman.',
	'bouton_radio_enregistrement_obligatoire' => 'Aou lé néséser fé zwé lanrozistroman po anvwa out komisyon (bann zitilzatèr i dwa mèt ladrès imèl pou abonn azot).',
	'bouton_radio_moderation_priori' => 'Modèr-dovan (bann komisyon lé publyé dann figirwèb piblik, sèlman kan komandèr la apiyé).

', # MODIF
	'bouton_radio_modere_abonnement' => 'In labonman lé nesèsèr',
	'bouton_radio_modere_posteriori' => 'lé modèré apré konfirmasyon ', # MODIF
	'bouton_radio_modere_priori' => 'lé modèré-dovan', # MODIF
	'bouton_radio_publication_immediate' => 'Modékri lé publyé sir losan (bann komisyon lé visib toutswit apré zot la anvway ali ; bann komander sitwèb i pé dégrèn ali aprè).',

	// F
	'form_pet_message_commentaire' => 'Inn modékri, inn ti lavi, inn komantèr ?',
	'forum' => 'Forom kozman',
	'forum_acces_refuse' => 'Ou néna pli lapermisyon pou gèt dann bann forom-la.',
	'forum_attention_dix_caracteres' => '<b>Tansyon pangar !</b> out modékri néna mwin 10 karaktèr-linprimri. Lé pa asé pou anrozistr ali.',
	'forum_attention_trois_caracteres' => '<b>Tansyon pangar !</b> Lo non ou la doné nana mwin 3 karactèr-linprimri.Sa lé pa asé pou anrozistr ali.',
	'forum_attention_trop_caracteres' => '<b>TANSYON@circ@ !</b> out’ mèzaz lé tro long’ (@compte@ karaktèr-linprimri)@circ@ : pour giny anrozistré, li doi pa fé pli dé @max@ karaktèr-linprimri', # MODIF
	'forum_avez_selectionne' => 'Ou la swazi :',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>tèrla</a> pour asévé.',
	'forum_forum' => 'forom kozman',
	'forum_info_modere' => 'Forom kozman lé modéré-dovan : lé néséser inn komander la finn konfirm ali pour out kontribusyon i aparé an liyn.

', # MODIF
	'forum_lien_hyper' => '<b>Gatiraz</b> (lé pa obligatwar)', # MODIF
	'forum_message_definitif' => 'Modékri-la lé fini : anvwa ali si lo sitwèb',
	'forum_message_trop_long' => 'Out modékri lé tro lon. Li dwa pa dépas plid 20000 karaktèr-linprimri.', # MODIF
	'forum_ne_repondez_pas' => 'Pou réponn limél-la, anserv lo forom kozman ou sava trouv tèrla (réponn pa èk inn ot limèl mé zizt inn modékri sir lo sitwèb) :', # MODIF
	'forum_page_url' => '(Si out modékri li ranvwa si inn lartik si lo Wèb o inn ot paz pli konplé déor, mèrsi mèt anba lo non lapazwèb èk son ladrès URL.)',
	'forum_poste_par' => 'Modékri-la, @parauteur@ la post ali pou réponn out lartik.', # MODIF
	'forum_qui_etes_vous' => '<b>Kisa ou lé ?</b> (réponn lé pa obligatwar)', # MODIF
	'forum_texte' => 'Lo tèks out modékri :', # MODIF
	'forum_titre' => 'Non :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Konfirm out swa',
	'forum_voir_avant' => 'Artourn gét modékri-la avann konfirm ali', # MODIF
	'forum_votre_email' => 'Out ladrès imèl :', # MODIF
	'forum_votre_nom' => 'Out vrénon (ou ti-non-gaté) :', # MODIF
	'forum_vous_enregistrer' => 'Pou mèt ansanm dann forom-la, ifo anrozistr aou. Mersi pou mèt anba latèr nondkod-lidantité sak ni la donn aou. Si ou lé pa anrozistré, i dwa',
	'forum_vous_inscrire' => 'inskri a ou </a>.',

	// I
	'icone_poster_message' => 'Anvwa inn modékri',
	'icone_suivi_forum' => 'Swiv lo forom piblik sir figirwèb : @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'Swiv/aranz bann forom',
	'icone_supprimer_message' => 'Dégrèn modékri-la',
	'icone_valider_message' => 'Konfirm modékri-la',
	'info_activer_forum_public' => '<i>Swazi inn manyir lamodérasyon otomatik pou bann forom piblik :</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplik lo swa ou la fé pou lamodérasyon :',
	'info_desactiver_forum_public' => 'Apiy tèrla, pou détour litilizasyon tout bann forom piblik. Ou sra touzou kav permèt bann forom-la èk bann zartik (dann désertin ka ou sava désid) ; mé nora pwinn forom èk bann rubrik, bann tit-nouvèl, é tousala.',
	'info_envoi_forum' => 'Anvwa tout bann modékri sak i sort dann bann forom , pou tout bann lotèr lartik lyé ',
	'info_fonctionnement_forum' => 'Koman forom-la i pé roul ron :',
	'info_gauche_suivi_forum_2' => 'Paz <i>swivi bann forom</i> lé inn zoutiy pou zèr an liyn out sit (pa inn léspas kozman o lékritir). Li afis tout bann kontribusyon sak lé prézanté dann tout bann forom out sit i ébèrz (kiswa forom-dodan, forom-déor, tousala...). Li permé zèr bann kontribusyon-la.', # MODIF
	'info_liens_syndiques_3' => 'bann forom',
	'info_liens_syndiques_4' => 'lé',
	'info_liens_syndiques_5' => 'forom',
	'info_liens_syndiques_6' => 'lé',
	'info_liens_syndiques_7' => 'i espèr lakonfirmasyon',
	'info_mode_fonctionnement_defaut_forum_public' => 'Lo fonksionman otomatik (sanswa) pou bann forom-déor (piblik)',
	'info_option_email' => 'Kank inn vizitèr i mèt inn modékri dann forom sou inn lartik
bann lotèr i pé konèt a li
sanm inn limèl. Indik tèrla si ou vé anserv lopsyon-la ?', # MODIF
	'info_pas_de_forum' => 'néna pwinn forom',
	'item_activer_forum_administrateur' => 'Fé zwé lo forom bann komandèr',
	'item_desactiver_forum_administrateur' => 'Défalk bann forom-komandèr',

	// L
	'lien_reponse_article' => 'Réponn lartik-la',
	'lien_reponse_breve_2' => 'Répons pou tit-nouvèl',
	'lien_reponse_rubrique' => 'Répons pou rubrik-la',
	'lien_reponse_site_reference' => 'Répons pou sit-la :', # MODIF

	// O
	'onglet_messages_internes' => 'Bann modékri-dodan',
	'onglet_messages_publics' => 'Bann modékri-déor',
	'onglet_messages_vide' => 'Bann modékri san tèks',

	// R
	'repondre_message' => 'Po réponn modékri-la',

	// T
	'titre_cadre_forum_administrateur' => 'Forom privé bann komandèr',
	'titre_cadre_forum_interne' => 'Forom dodan',
	'titre_forum' => 'Forom ',
	'titre_forum_suivi' => 'Swivi bann forom',
	'titre_page_forum_suivi' => 'Swivi bann forom',
];
